Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(338)

Unified Diff: components/offline_pages/offline_page_item.h

Issue 1694863003: Refactor the offline page storage to include client namespace and id. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/offline_pages/offline_page_item.h
diff --git a/components/offline_pages/offline_page_item.h b/components/offline_pages/offline_page_item.h
index a7bf8c8fa1d3f9424aa941d2f64d3e98e63e5ab0..0b7218bdb40ea8d59f16fea8f804661107c2add1 100644
--- a/components/offline_pages/offline_page_item.h
+++ b/components/offline_pages/offline_page_item.h
@@ -16,6 +16,8 @@
namespace offline_pages {
+class ClientId;
+
// Metadata of the offline page.
struct OfflinePageItem {
public:
@@ -27,11 +29,13 @@ struct OfflinePageItem {
OfflinePageItem();
OfflinePageItem(const GURL& url,
- int64_t bookmark_id,
+ int64_t offline_id,
+ const ClientId& client_id,
const base::FilePath& file_path,
int64_t file_size);
OfflinePageItem(const GURL& url,
- int64_t bookmark_id,
+ int64_t offline_id,
+ const ClientId& client_id,
const base::FilePath& file_path,
int64_t file_size,
const base::Time& creation_time);
@@ -50,8 +54,13 @@ struct OfflinePageItem {
// The URL of the page.
GURL url;
- // The Bookmark ID related to the offline page.
- int64_t bookmark_id;
+ // The Offline (internal) ID related to the offline page.
+ int64_t offline_id;
+
+ // The Client ID (external) related to the offline page.
+ std::string client_id_namespace;
+ std::string client_id;
+
// Version of the offline page item.
int version;
// The file path to the archive with a local copy of the page.

Powered by Google App Engine
This is Rietveld 408576698